==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/ContainerStateWaitingBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ContainerStateWaitingBuilder extends io.fabric8.kubernetes.api.model.ContainerStateWaitingFluentImpl<io.fabric8.kubernetes.api.model.ContainerStateWaitingBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.ContainerStateWaiting,io.fabric8.kubernetes.api.model.ContainerStateWaitingBuilder>{
  public ContainerStateWaitingBuilder() {
    this(false);
  }
  public ContainerStateWaitingBuilder(java.lang.Boolean validationEnabled) {
    this(new ContainerStateWaiting(), validationEnabled);
  }
  public ContainerStateWaitingBuilder(io.fabric8.kubernetes.api.model.ContainerStateWaitingFluent<?> fluent) {
    this(fluent, false);
  }
  public ContainerStateWaitingBuilder(io.fabric8.kubernetes.api.model.ContainerStateWaitingFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ContainerStateWaiting(), validationEnabled);
  }
  public ContainerStateWaitingBuilder(io.fabric8.kubernetes.api.model.ContainerStateWaitingFluent<?> fluent,io.fabric8.kubernetes.api.model.ContainerStateWaiting instance) {
    this(fluent, instance, false);
  }
  public ContainerStateWaitingBuilder(io.fabric8.kubernetes.api.model.ContainerStateWaitingFluent<?> fluent,io.fabric8.kubernetes.api.model.ContainerStateWaiting instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    this.validationEnabled = validationEnabled; 
  }
  public ContainerStateWaitingBuilder(io.fabric8.kubernetes.api.model.ContainerStateWaiting instance) {
    this(instance,false);
  }
  public ContainerStateWaitingBuilder(io.fabric8.kubernetes.api.model.ContainerStateWaiting instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.ContainerStateWaitingFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.ContainerStateWaiting build() {
    ContainerStateWaiting buildable = new ContainerStateWaiting(fluent.getMessage(),fluent.getReason());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContainerStateWaitingBuilder that = (ContainerStateWaitingBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/ContainerStateWaitingBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ContainerStateWaitingBuilder extends io.fabric8.kubernetes.api.model.ContainerStateWaitingFluentImpl<io.fabric8.kubernetes.api.model.ContainerStateWaitingBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.ContainerStateWaiting,io.fabric8.kubernetes.api.model.ContainerStateWaitingBuilder>{
  public ContainerStateWaitingBuilder() {
    this(false);
  }
  public ContainerStateWaitingBuilder(java.lang.Boolean validationEnabled) {
    this(new ContainerStateWaiting(), validationEnabled);
  }
  public ContainerStateWaitingBuilder(io.fabric8.kubernetes.api.model.ContainerStateWaitingFluent<?> fluent) {
    this(fluent, false);
  }
  public ContainerStateWaitingBuilder(io.fabric8.kubernetes.api.model.ContainerStateWaitingFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ContainerStateWaiting(), validationEnabled);
  }
  public ContainerStateWaitingBuilder(io.fabric8.kubernetes.api.model.ContainerStateWaitingFluent<?> fluent,io.fabric8.kubernetes.api.model.ContainerStateWaiting instance) {
    this(fluent, instance, false);
  }
  public ContainerStateWaitingBuilder(io.fabric8.kubernetes.api.model.ContainerStateWaitingFluent<?> fluent,io.fabric8.kubernetes.api.model.ContainerStateWaiting instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ContainerStateWaitingBuilder(io.fabric8.kubernetes.api.model.ContainerStateWaiting instance) {
    this(instance,false);
  }
  public ContainerStateWaitingBuilder(io.fabric8.kubernetes.api.model.ContainerStateWaiting instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.ContainerStateWaitingFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.ContainerStateWaiting build() {
    ContainerStateWaiting buildable = new ContainerStateWaiting(fluent.getMessage(),fluent.getReason());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContainerStateWaitingBuilder that = (ContainerStateWaitingBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
